@@ -6,10 +6,10 @@ use Carp;
 use File::Basename;
 use File::Path;
 use List::Util qw(first);
-use Class::Std::Storable;
+use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
-our $VERSION='2.00_17';
+our $VERSION='2.00_25';
 
 my %types_of    :ATTR(:name<types>      :default<[]>);
 my %message_of  :ATTR(:name<message>    :default<()>);
@@ -118,9 +118,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 391 $
+ $Rev: 427 $
  $LastChangedBy: kutterma $
- $Id: Definitions.pm 391 2007-11-17 21:56:13Z kutterma $
+ $Id: Definitions.pm 427 2007-12-02 22:20:24Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Definitions.pm $
 
 =cut
