@@ -2,8 +2,6 @@ package SOAP::WSDL::Server::CGI;
 use strict;
 use warnings;
 
-use Encode;
-
 use HTTP::Request;
 use HTTP::Response;
 use HTTP::Status;
@@ -11,16 +9,17 @@ use HTTP::Headers;
 use Scalar::Util qw(blessed);
 
 use Class::Std::Fast::Storable;
+# use Class::Std::Storable;
 
 use base qw(SOAP::WSDL::Server);
 
-use version; our $VERSION = qv('2.00.09');
+our $VERSION=q{2.00_25};
 
 # mostly copied from SOAP::Lite. Unfortunately we can't use SOAP::Lite's CGI
 # server directly - we would have to swap out it's base class...
 #
 # This should be a warning for us: We should not handle methods via inheritance,
-# but via some plugin mechanism, to allow alternative handlers to be plugged
+# but via some plugin mechanism, to allow alternative handlers to be plugge 
 # in.
 
 sub handle {
@@ -28,7 +27,7 @@ sub handle {
     my $response;
     my $length = $ENV{'CONTENT_LENGTH'} || 0;
 
-    if (!$length) {
+    if (!$length) {     
         $response = HTTP::Response->new(411); # LENGTH REQUIRED
         $self->_output($response);
         return;
@@ -39,9 +38,7 @@ sub handle {
     }
 
     my $content = q{};
-    my $buffer;
-
-    # do we need to use bytes; here ?
+    my $buffer; 
     binmode(STDIN);
     while (read(STDIN,$buffer,$length - length($content))) {
         $content .= $buffer;
@@ -51,10 +48,10 @@ sub handle {
         $ENV{'REQUEST_METHOD'} || '' => $ENV{'SCRIPT_NAME'},
         HTTP::Headers->new(
             map {
-                    (/^HTTP_(.+)/i
-                        ? ($1=~m/SOAPACTION/)
+                    (/^HTTP_(.+)/i 
+                        ? ($1=~m/SOAPACTION/) 
                             ?('SOAPAction')
-                            :($1)
+                            :($1) 
                         : $_
                      ) => $ENV{$_}
             } keys %ENV),
@@ -66,27 +63,23 @@ sub handle {
     my $response_message = eval { $self->SUPER::handle($request) };
     # caveat: SOAP::WSDL::SOAP::Typelib::Fault11 is false in bool context...
     if ($@ || blessed $@) {
-        my $exception = $@;
         $response = HTTP::Response->new(500);
-        $response->header('Content-type' => 'text/xml; charset="utf-8"');
-        if (blessed($exception)) {
+        if (blessed $@) {
             $response->content( $self->get_serializer->serialize({
-                    body => $exception
+                    body =>$@
                 })
             );
         }
         else {
-            $response->content($exception);
+            $response->content($@);
         }
     }
     else {
         $response = HTTP::Response->new(200);
-        $response->header('Content-type' => 'text/xml; charset="utf-8"');
-        $response->content( encode('utf8', $response_message ) );
-        {
-            use bytes;
-            $response->header('Content-length', length $response_message);
-        }
+        $response->header(
+            'Content-type' => 'text/xml; charset="utf-8"'
+        );
+        $response->content( $response_message );
     }
 
     $self->_output($response);
@@ -97,14 +90,15 @@ sub _output :PRIVATE {
     my ($self, $response) = @_;
     # imitate nph- cgi for IIS (pointed by Murray Nesbitt)
     my $status = defined($ENV{'SERVER_SOFTWARE'}) && $ENV{'SERVER_SOFTWARE'}=~/IIS/
-        ? $ENV{SERVER_PROTOCOL} || 'HTTP/1.0'
+        ? $ENV{SERVER_PROTOCOL} || 'HTTP/1.0' 
         : 'Status:';
 
     my $code = $response->code;
-    binmode(STDOUT);
+    binmode(STDOUT); 
     print STDOUT "$status $code ", HTTP::Status::status_message($code)
         , "\015\012", $response->headers_as_string("\015\012")
         , "\015\012", $response->content;
+    
 }
 
 1;
@@ -117,38 +111,11 @@ SOAP::WSDL::Server::CGI - CGI based SOAP server
 
 =head1 SYNOPSIS
 
- use MyServer::TestService::TestPort;
- my $server = MyServer::TestService::TestPort->new({
-    dispatch_to => 'main',
-    transport_class => 'SOAP::WSDL::Server::CGI',   # optional, default
- });
- $server->handle();
-
-=head1 USAGE
-
-To use SOAP::WSDL::Server::CGI efficiently, you should first create a server
-interface using L<wsdl2perl.pl|wsdl2perl.pl>.
-
-SOAP::WSDL::Server dispatches all calls to appropriately named methods in the
-class or object set via C<dispatch_to>.
-
-See the generated server class on details.
-
 =head1 DESCRIPTION
 
-Lightweight CGI based SOAP server. SOAP::WSDL::Server::CGI does not provide
-the fancier things of CGI handling, like URL parsing, parameter extraction
-or the like, but provides a basic SOAP server using SOAP::WSDL::Server.
-
-=head1 METHODS
-
-=head2 handle
-
-See synopsis above.
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2004-2008 Martin Kutter.
+Copyright 2004-2007 Martin Kutter.
 
 This file is part of SOAP-WSDL. You may distribute/modify it under the same
 terms as perl itself
